@@ -46,11 +46,6 @@ class WorkspaceVersionRecordsCommand extends Command
      */
     protected $allWorkspaces = [0 => 'Live Workspace'];
 
-    public function __construct(private readonly ConnectionPool $connectionPool)
-    {
-        parent::__construct();
-    }
-
     /**
      * Array with all records found when traversing the database
      * @var array
@@ -71,6 +66,11 @@ class WorkspaceVersionRecordsCommand extends Command
         'invalid_workspace' => [],
     ];
 
+    public function __construct(private readonly ConnectionPool $connectionPool)
+    {
+        parent::__construct();
+    }
+
     /**
      * Configuring the command options
      */
@@ -384,7 +384,7 @@ class WorkspaceVersionRecordsCommand extends Command
                     $io->writeln('Flushing record "' . $table . ':' . $uid . '"');
                 }
                 if (!$dryRun) {
-                    $dataHandler->deleteEl($table, $uid, true, true);
+                    $dataHandler->deleteAction($table, $uid, true, true);
                     if (!empty($dataHandler->errorLog)) {
                         $errorMessage = array_merge(['DataHandler reported an error'], $dataHandler->errorLog);
                         $io->error($errorMessage);
